# Utilities to compute and analyze protein covariation

## Description

This pack has some tools to make easier to work with protein covariation.

## Package content

### PDB to sequence mapper

### Load distances from MIToS

### MSA to sequence mapper

### ROC curve and auc calculation.

## How to install

    > pip install dist/xi_covutils-x.y.z

## Running tests

    > pytest tests
    
## Documentation

Automatic documentation from code is in the 'docs' folder.

## Examples



